@@ -7,7 +7,7 @@ use warnings;
 
 package Math::Polygon;
 use vars '$VERSION';
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 
 use Math::Polygon::Calc;
@@ -154,6 +154,12 @@ sub contains($)
 }
 
 
+sub distance($)
+{   my ($self, $point) = @_;
+    polygon_distance($point, $self->points);
+}
+
+
 sub isClosed() { polygon_is_closed(shift->points) }
 
 
